@@ -809,12 +809,7 @@ instance UN.ParUnsafe IVar Par  where
   unsafeParIO  = unsafeParIO
 #endif
 
-instance Functor Par where
-   fmap f xs = xs >>= return . f
 
-instance Applicative Par where
-   (<*>) = ap
-   pure  = return
 
 #ifdef NEW_GENERIC
 instance PU.ParMonad Par where
@@ -873,7 +868,7 @@ dbgTakeMVar msg mv =
    doDebugStuff = do printf "This takeMVar blocked indefinitely!: %s\n" msg
                      error "failed"
 
--- | For debugging purposes.  This can help us figure out (but an ugly
+-- | For debugging purposes.  This can help us figure out (by an ugly
 --   process of elimination) which MVar reads are leading to a "Thread
 --   blocked indefinitely" exception.
 {-
